@@ -7,6 +7,7 @@ import (
 	"time"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/port"
 	"github.com/rs/zerolog/log"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -28,8 +29,7 @@ type PortForwarder struct {
 	stopChan, readyChan chan struct{}
 	active              bool
 	path                string
-	container           string
-	ports               []string
+	tunnel              port.PortTunnel
 	age                 time.Time
 }
 
@@ -57,58 +57,56 @@ func (p *PortForwarder) SetActive(b bool) {
 	p.active = b
 }
 
-// Ports returns the forwarded ports mappings.
-func (p *PortForwarder) Ports() []string {
-	return p.ports
+// Port returns the port mapping.
+func (p *PortForwarder) Port() string {
+	return p.tunnel.PortMap()
+}
+
+// ContainerPort returns the container port.
+func (p *PortForwarder) ContainerPort() string {
+	return p.tunnel.ContainerPort
+}
+
+// LocalPort returns the local port.
+func (p *PortForwarder) LocalPort() string {
+	return p.tunnel.LocalPort
 }
 
 // Path returns the pod resource path.
 func (p *PortForwarder) Path() string {
-	return PortForwardID(p.path, p.container)
+	return PortForwardID(p.path, p.tunnel.Container, p.tunnel.PortMap())
 }
 
-// PortForwardID computes port-forward identifier.
-func PortForwardID(path, co string) string {
-	return path + ":" + co
+// ID returns a pf id.
+func (p *PortForwarder) ID() string {
+	return PortForwardID(p.path, p.tunnel.Container, p.tunnel.PortMap())
 }
 
 // Container returns the target's container.
 func (p *PortForwarder) Container() string {
-	return p.container
+	return p.tunnel.Container
 }
 
 // Stop terminates a port forward.
 func (p *PortForwarder) Stop() {
-	log.Debug().Msgf("<<< Stopping PortForward %q %v", p.path, p.ports)
+	log.Debug().Msgf("<<< Stopping PortForward %s", p.ID())
 	p.active = false
 	close(p.stopChan)
 }
 
 // FQN returns the portforward unique id.
 func (p *PortForwarder) FQN() string {
-	return p.path + ":" + p.container
+	return p.path + ":" + p.tunnel.Container
 }
 
 // HasPortMapping checks if port mapping is defined for this fwd.
-func (p *PortForwarder) HasPortMapping(m string) bool {
-	for _, mapping := range p.ports {
-		if mapping == m {
-			return true
-		}
-	}
-	return false
+func (p *PortForwarder) HasPortMapping(portMap string) bool {
+	return p.tunnel.PortMap() == portMap
 }
 
 // Start initiates a port forward session for a given pod and ports.
-func (p *PortForwarder) Start(path, co string, tt []client.PortTunnel) (*portforward.PortForwarder, error) {
-	if len(tt) == 0 {
-		return nil, fmt.Errorf("no ports assigned")
-	}
-	fwds, addrs := make([]string, 0, len(tt)), make([]string, 0, len(tt))
-	for _, t := range tt {
-		fwds, addrs = append(fwds, t.PortMap()), append(addrs, t.Address)
-	}
-	p.path, p.container, p.ports, p.age = path, co, fwds, time.Now()
+func (p *PortForwarder) Start(path string, tt port.PortTunnel) (*portforward.PortForwarder, error) {
+	p.path, p.tunnel, p.age = path, tt, time.Now()
 
 	ns, n := client.Namespaced(path)
 	auth, err := p.Client().CanI(ns, "v1/pods", []string{client.GetVerb})
@@ -155,10 +153,10 @@ func (p *PortForwarder) Start(path, co string, tt []client.PortTunnel) (*portfor
 		Name(n).
 		SubResource("portforward")
 
-	return p.forwardPorts("POST", req.URL(), addrs, fwds)
+	return p.forwardPorts("POST", req.URL(), tt.Address, tt.PortMap())
 }
 
-func (p *PortForwarder) forwardPorts(method string, url *url.URL, addrs, ports []string) (*portforward.PortForwarder, error) {
+func (p *PortForwarder) forwardPorts(method string, url *url.URL, addr, portMap string) (*portforward.PortForwarder, error) {
 	cfg, err := p.Client().Config().RESTConfig()
 	if err != nil {
 		return nil, err
@@ -169,12 +167,17 @@ func (p *PortForwarder) forwardPorts(method string, url *url.URL, addrs, ports [
 	}
 	dialer := spdy.NewDialer(upgrader, &http.Client{Transport: transport}, method, url)
 
-	return portforward.NewOnAddresses(dialer, addrs, ports, p.stopChan, p.readyChan, p.Out, p.ErrOut)
+	return portforward.NewOnAddresses(dialer, []string{addr}, []string{portMap}, p.stopChan, p.readyChan, p.Out, p.ErrOut)
 }
 
 // ----------------------------------------------------------------------------
 // Helpers...
 
+// PortForwardID computes port-forward identifier.
+func PortForwardID(path, co, portMap string) string {
+	return path + "|" + co + "|" + portMap
+}
+
 func codec() (serializer.CodecFactory, runtime.ParameterCodec) {
 	scheme := runtime.NewScheme()
 	gv := schema.GroupVersion{Group: "", Version: "v1"}
