@@ -127,6 +127,9 @@ func (b *Browser) SetInstance(path string) {
 // Start initializes browser updates.
 func (b *Browser) Start() {
 	b.app.Config.ValidateFavorites()
+	if err := b.app.switchNS(b.GetModel().GetNamespace()); err != nil {
+		log.Error().Err(err).Msgf("ns switch failed")
+	}
 	if err := b.app.Config.Save(); err != nil {
 		log.Error().Err(err).Msgf("Config Save")
 	}
