@@ -3,12 +3,9 @@ package view
 import (
 	"fmt"
 	"math"
-	"regexp"
 	"strings"
 
-	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/port"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tview"
 	"github.com/rs/zerolog/log"
@@ -47,13 +44,13 @@ func ShowPortForwards(v ResourceViewer, path string, ports port.ContainerPortSpe
 		coField.SetPlaceholder("Enter a container name/port")
 	}
 	f.AddInputField("Local Port:", p2, fieldLen, nil, nil)
-	poField := f.GetFormItemByLabel("Local Port:").(*tview.InputField)
-	if poField.GetText() == "" {
-		poField.SetPlaceholder("Enter a local port")
+	loField := f.GetFormItemByLabel("Local Port:").(*tview.InputField)
+	if loField.GetText() == "" {
+		loField.SetPlaceholder("Enter a local port")
 	}
 	coField.SetChangedFunc(func(s string) {
 		port := extractPort(s)
-		poField.SetText(port)
+		loField.SetText(port)
 		p2 = port
 	})
 	f.AddInputField("Address:", address, fieldLen, nil, func(h string) {
@@ -69,11 +66,15 @@ func ShowPortForwards(v ResourceViewer, path string, ports port.ContainerPortSpe
 	}
 
 	f.AddButton("OK", func() {
-		if coField.GetText() == "" || poField.GetText() == "" {
+		if coField.GetText() == "" || loField.GetText() == "" {
 			v.App().Flash().Err(fmt.Errorf("container to local port mismatch"))
 			return
 		}
-		tt, err := port.ToTunnels(address, coField.GetText(), poField.GetText())
+		if !ports.MatchSpec(coField.GetText()) {
+			v.App().Flash().Err(fmt.Errorf("invalid container port"))
+			return
+		}
+		tt, err := port.ToTunnels(address, coField.GetText(), loField.GetText())
 		if err != nil {
 			v.App().Flash().Err(err)
 			return
@@ -121,26 +122,11 @@ func DismissPortForwards(v ResourceViewer, p *ui.Pages) {
 // ----------------------------------------------------------------------------
 // Helpers...
 
-func extractPort(p string) string {
-	rx := regexp.MustCompile(`\A([\w|-]+)/?([\w|-]+)?:?(\d+)?(╱UDP)?\z`)
-	mm := rx.FindStringSubmatch(p)
-	if len(mm) != 5 {
-		return p
-	}
-	for i := 3; i > 0; i-- {
-		if mm[i] != "" {
-			return mm[i]
-		}
-	}
-	return p
-}
-
-func extractContainer(p string) string {
-	tokens := strings.Split(p, ":")
-	if len(tokens) != 2 {
-		return render.NAValue
+func extractPort(coPort string) string {
+	tokens := strings.Split(coPort, "::")
+	if len(tokens) < 2 {
+		return ""
 	}
 
-	co, _ := client.Namespaced(tokens[0])
-	return co
+	return tokens[1]
 }
